@@ -1,7 +1,10 @@
 __submodules__ = ["core"]
 
+
 # <AUTOGEN_INIT>
 from snakebids.core import (
+    BidsInputs,
+    BidsInputsDict,
     bids,
     filter_list,
     generate_inputs,
@@ -12,6 +15,8 @@ from snakebids.core import (
 )
 
 __all__ = [
+    "BidsInputs",
+    "BidsInputsDict",
     "bids",
     "filter_list",
     "generate_inputs",
